import React from 'react';
import { LinkProps, NavLinkProps } from 'react-router-dom';
import { ObjectivTrackingOptions } from '@objectiv/tracker-react';

/**
 * Some extra options that may be useful for special cases, e.g. anchors without texts or external hrefs.
 */
declare type ReactRouterTrackingOptionsProp = {
    /**
     * All Objectiv tracking related options reside under this prop.
     * We omit `waitUntilTracked` because ReactRouter Link and NavLink have a `reloadDocument` with the same meaning.
     */
    objectiv?: Omit<ObjectivTrackingOptions, 'waitUntilTracked'>;
};

/**
 * Wrapped Link will accept all LinkProps and, optionally, ReactRouterTrackingOptionsProp.
 */
declare type TrackedLinkProps = LinkProps & ReactRouterTrackingOptionsProp;
/**
 * Wraps Link in a LinkContext and automatically instruments tracking PressEvent on click.
 */
declare const TrackedLink: React.ForwardRefExoticComponent<LinkProps & ReactRouterTrackingOptionsProp & React.RefAttributes<HTMLAnchorElement>>;

/**
 * Wrapped NavLink will accept all NavLinkProps and, optionally, ReactRouterTrackingOptionsProp.
 */
declare type TrackedNavLinkProps = NavLinkProps & ReactRouterTrackingOptionsProp;
/**
 * Wraps NavLink in a LinkContext and automatically instruments tracking PressEvent on click.
 */
declare const TrackedNavLink: React.ForwardRefExoticComponent<NavLinkProps & ReactRouterTrackingOptionsProp & React.RefAttributes<HTMLAnchorElement>>;

export { TrackedLink, TrackedLinkProps, TrackedNavLink, TrackedNavLinkProps };
